@@ -171,6 +171,7 @@ static unsigned get_type( unsigned uiProperty )
     case LIBMSI_PROPERTY_TITLE:
          return OLEVT_LPSTR;
 
+    case LIBMSI_PROPERTY_EDITTIME:
     case LIBMSI_PROPERTY_LASTPRINTED:
     case LIBMSI_PROPERTY_CREATED_TM:
     case LIBMSI_PROPERTY_LASTSAVED_TM:
@@ -311,7 +312,7 @@ static void read_properties_from_data( LibmsiOLEVariant *prop, const uint8_t *da
     unsigned i;
     LibmsiOLEVariant *property;
     uint32_t idofs, len;
-    char *str;
+    char *str = NULL;
 
     idofs = 8;
 
@@ -387,6 +388,7 @@ static void read_properties_from_data( LibmsiOLEVariant *prop, const uint8_t *da
         else if (type == proptype)
            ;
         else if( proptype == OLEVT_LPSTR) {
+            g_return_if_fail(str != NULL);
             if( type == OLEVT_I2 || type == OLEVT_I4) {
                 property->intval = atoi( str );
             } else if( type == OLEVT_FILETIME) {
